@@ -2,7 +2,7 @@ from datetime import datetime
 from datetime import timedelta
 
 def delta2dict( delta ):
-    """return dictionary of delta"""
+    """Accepts a delta, returns a dictionary of units"""
     delta = abs( delta )
     return { 
         'year'   : delta.days / 365 ,
@@ -13,10 +13,16 @@ def delta2dict( delta ):
         'microsecond' : delta.microseconds
     }
 
-def delta2human(delta, precision=2, past_format='{0} ago', future_format='in {0}'):
-    """return human readable delta string"""
-    the_format = past_format
-    if delta < timedelta(0): the_format = future_format
+def human(dt, precision=2, past_tense='{} ago', future_tense='in {}'):
+    """Accept a datetime or timedelta, return a human readable delta string"""
+    delta = dt
+    if type(dt) is not type(timedelta()):
+        delta = datetime.now() - dt
+     
+    the_tense = past_tense
+    if delta < timedelta(0):
+        the_tense = future_tense
+
     d = delta2dict( delta )
     hlist = [] 
     count = 0
@@ -28,12 +34,7 @@ def delta2human(delta, precision=2, past_format='{0} ago', future_format='in {0}
         hlist.append( '%s %s%s' % ( d[unit], unit, s ) )
         count += 1
     human_delta = ', '.join( hlist )
-    return the_format.format(human_delta) 
-
-def human(d, precision=2, format_past='{0} ago', format_future='in {0}'):
-    """Pass datetime we will return human delta string"""
-    delta = datetime.now() - d
-    return delta2human( delta, precision, format_past, format_future ) 
+    return the_tense.format(human_delta) 
 
 if __name__ == "__main__": 
     from test_ago import test_output
